@@ -1,5 +1,5 @@
 ## git2r, R bindings to the libgit2 library.
-## Copyright (C) 2013-2015 The git2r contributors
+## Copyright (C) 2013-2018 The git2r contributors
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License, version 2,
@@ -14,7 +14,7 @@
 ## with this program; if not, write to the Free Software Foundation, Inc.,
 ## 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-library(git2r)
+library("git2r")
 
 ## For debugging
 sessionInfo()
@@ -24,6 +24,3 @@ stopifnot(identical(names(libgit2_features()),
 
 stopifnot(identical(names(libgit2_version()),
                     c("major", "minor", "rev")))
-
-stopifnot(identical(length(libgit2_sha()), 1L))
-stopifnot(identical(nchar(libgit2_sha()[1]), 40L))
