@@ -1,5 +1,5 @@
 ## git2r, R bindings to the libgit2 library.
-## Copyright (C) 2013-2015 The git2r contributors
+## Copyright (C) 2013-2018 The git2r contributors
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License, version 2,
@@ -14,7 +14,7 @@
 ## with this program; if not, write to the Free Software Foundation, Inc.,
 ## 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-library(git2r)
+library("git2r")
 
 ## For debugging
 sessionInfo()
@@ -57,30 +57,29 @@ stopifnot(identical(merge_base(commit_2, commit_3), commit_1))
 
 ## Checkout master
 b <- branches(repo)
-checkout(b[sapply(b, slot, "name") == "master"][[1]], force=TRUE)
+checkout(b[sapply(b, "[", "name") == "master"][[1]], force=TRUE)
 
 ## Merge branch 1
-m_1 <- git2r:::merge_branch(
-    b[sapply(b, slot, "name") == "branch1"][[1]],
-    commit_on_success = TRUE,
-    merger = default_signature(repo))
+m_1 <- merge(b[sapply(b, "[", "name") == "branch1"][[1]])
+stopifnot(identical(m_1$fast_forward, TRUE))
+stopifnot(identical(m_1$conflicts, FALSE))
+stopifnot(identical(sha(m_1), NA_character_))
 
-stopifnot(identical(m_1@fast_forward, TRUE))
-stopifnot(identical(m_1@conflicts, FALSE))
-stopifnot(identical(m_1@sha, character(0)))
+## Merge branch 1 again
+m_1_again <- merge(b[sapply(b, "[", "name") == "branch1"][[1]])
+stopifnot(identical(m_1_again$up_to_date, TRUE))
+stopifnot(identical(m_1_again$fast_forward, FALSE))
+stopifnot(identical(m_1_again$conflicts, FALSE))
+stopifnot(identical(sha(m_1_again), NA_character_))
 
 ## Merge branch 2
-m_2 <- git2r:::merge_branch(
-    b[sapply(b, slot, "name") == "branch2"][[1]],
-    commit_on_success = TRUE,
-    merger = default_signature(repo))
-
-stopifnot(identical(m_2@fast_forward, FALSE))
-stopifnot(identical(m_2@conflicts, FALSE))
-stopifnot(identical(m_2@sha, commits(repo)[[1]]@sha))
+m_2 <- merge(b[sapply(b, "[", "name") == "branch2"][[1]])
+stopifnot(identical(m_2$fast_forward, FALSE))
+stopifnot(identical(m_2$conflicts, FALSE))
+stopifnot(identical(sha(m_2), sha(commits(repo)[[1]])))
 
 ## Create third branch, checkout, change file and commit
-b_3 <- branch_create(lookup(repo, m_2@sha), "branch3")
+b_3 <- branch_create(lookup(repo, sha(m_2)), "branch3")
 checkout(b_3)
 writeLines(c("Lorem ipsum dolor amet sit, consectetur adipisicing elit, sed do",
              "eiusmod tempor incididunt ut labore et dolore magna aliqua."),
@@ -91,23 +90,36 @@ commit(repo, "Commit message branch 3")
 ## Checkout master and create a change that creates a conflict on
 ## merge
 b <- branches(repo)
-checkout(b[sapply(b, slot, "name") == "master"][[1]], force=TRUE)
+checkout(b[sapply(b, "[", "name") == "master"][[1]], force=TRUE)
 writeLines(c("Lorem ipsum dolor sit amet, adipisicing consectetur elit, sed do",
              "eiusmod tempor incididunt ut labore et dolore magna aliqua."),
            con = file.path(path, "test.txt"))
 add(repo, "test.txt")
 commit(repo, "Some commit message branch 1")
 
-## Merge branch 3
-m_3 <- git2r:::merge_branch(
-    b[sapply(b, slot, "name") == "branch3"][[1]],
-    commit_on_success = TRUE,
-    merger = default_signature(repo))
+## Merge branch 3 with fail = TRUE
+m_3 <- merge(b[sapply(b, "[", "name") == "branch3"][[1]], fail = TRUE)
+stopifnot(identical(m_3$up_to_date, FALSE))
+stopifnot(identical(m_3$fast_forward, FALSE))
+stopifnot(identical(m_3$conflicts, TRUE))
+stopifnot(identical(sha(m_3), NA_character_))
+m_3
 
-stopifnot(identical(m_3@up_to_date, FALSE))
-stopifnot(identical(m_3@fast_forward, FALSE))
-stopifnot(identical(m_3@conflicts, TRUE))
-stopifnot(identical(m_3@sha, character(0)))
+## Check status; Expect to have a clean working directory
+wd <- structure(list(staged = structure(list(), .Names = character(0)),
+                     unstaged = structure(list(), .Names = character(0)),
+                     untracked = structure(list(), .Names = character(0))),
+                .Names = c("staged", "unstaged", "untracked"),
+                class = "git_status")
+stopifnot(identical(status(repo), wd))
+
+## Merge branch 3
+m_3 <- merge(b[sapply(b, "[", "name") == "branch3"][[1]])
+stopifnot(identical(m_3$up_to_date, FALSE))
+stopifnot(identical(m_3$fast_forward, FALSE))
+stopifnot(identical(m_3$conflicts, TRUE))
+stopifnot(identical(sha(m_3), NA_character_))
+m_3
 
 ## Check status; Expect to have one unstaged unmerged conflict.
 stopifnot(identical(status(repo),
